E200
====

E200 is designed to load and handle data generated at FACET at the 
SLAC National Accelerator Laboratory. In particular, it makes
loading datasets and images much simpler.

Documentation can be found at:

http://e200.readthedocs.org
